@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2014 Gentoo Foundation
+ * Copyright 2005-2018 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
  *
  * Copyright 2005-2010 Ned Ludd        - <solar@gentoo.org>
@@ -203,6 +203,7 @@ qmerge_initialize(void)
 struct qmerge_bv_state {
 	const char *catname;
 	const char *pkgname;
+	const char *slot;
 	char buf[4096];
 	char *retbuf;
 };
@@ -219,19 +220,20 @@ qmerge_best_version_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
 {
 	struct qmerge_bv_state *state = priv;
 	if (qlist_match(pkg_ctx, state->buf, NULL, true))
-		snprintf(state->retbuf, sizeof(state->buf), "%s/%s",
-			pkg_ctx->cat_ctx->name, pkg_ctx->name);
+		snprintf(state->retbuf, sizeof(state->buf), "%s/%s:%s",
+			 pkg_ctx->cat_ctx->name, pkg_ctx->name, state->slot);
 	return 0;
 }
 
 static char *
-best_version(const char *catname, const char *pkgname)
+best_version(const char *catname, const char *pkgname, const char *slot)
 {
 	static int vdb_check = 1;
 	static char retbuf[4096];
 	struct qmerge_bv_state state = {
 		.catname = catname,
 		.pkgname = pkgname,
+		.slot = slot,
 		.retbuf = retbuf,
 	};
 
@@ -252,8 +254,8 @@ best_version(const char *catname, const char *pkgname)
 	}
 
 	retbuf[0] = '\0';
-	snprintf(state.buf, sizeof(state.buf), "%s%s%s",
-		catname ? : "", catname ? "/" : "", pkgname);
+	snprintf(state.buf, sizeof(state.buf), "%s%s%s:%s",
+		 catname ? : "", catname ? "/" : "", pkgname, slot);
 	q_vdb_foreach_pkg(qmerge_best_version_cb, &state, qmerge_filter_cat);
 
  done:
@@ -359,7 +361,8 @@ qprint_tree_node(int level, const depend_atom *atom, const struct pkg_t *pkg)
 	if (!pretend)
 		return 0;
 
-	p = best_version(pkg->CATEGORY, atom->PN);
+	p = best_version(pkg->CATEGORY, atom->PN, pkg->SLOT);
+
 	if (strlen(p) < 1) {
 		c = 'N';
 		snprintf(buf, sizeof(buf), "%sN%s", GREEN, NORM);
@@ -466,9 +469,9 @@ pkg_run_func_at(int dirfd, const char *vdb_path, const char *phases, const char
 		"FILESDIR=/.does/not/exist/anywhere\n"
 		"MERGE_TYPE=binary\n"
 		"ROOT='%4$s'\n"
-		"EROOT=\"${EPREFIX%%/}/${ROOT#/}\"\n"
+		"EROOT=\"${EPREFIX%%/}/${ROOT#/}/\"\n"
 		"D=\"%5$s\"\n"
-		"ED=\"${EPREFIX%%/}/${D#/}\"\n"
+		"ED=\"${EPREFIX%%/}/${D#/}/\"\n"
 		"T=\"%6$s\"\n"
 		/* Finally run the func */
 		"%7$s%2$s\n"
@@ -844,7 +847,8 @@ pkg_merge(int level, const depend_atom *atom, const struct pkg_t *pkg)
 
 						ratom = atom_explode(buf);
 
-						p = best_version(subpkg->CATEGORY, subpkg->PF);
+						p = best_version(subpkg->CATEGORY, subpkg->PF, subpkg->SLOT);
+
 						/* we dont want to remerge equal versions here */
 						IF_DEBUG(fprintf(stderr, "+Installed: %s\n", p));
 						if (strlen(p) < 1)
@@ -1373,7 +1377,7 @@ print_Pkg(int full, const depend_atom *atom, const struct pkg_t *pkg)
 		if (strcmp(pkg->REPO, "gentoo") != 0)
 			printf(" %sRepo%s:%s %s\n", DKGREEN, YELLOW, NORM, pkg->REPO);
 
-	if ((p = best_version(pkg->CATEGORY, atom->PN)) != NULL) {
+	if ((p = best_version(pkg->CATEGORY, atom->PN, pkg->SLOT)) != NULL) {
 		if (*p) {
 			int ret;
 			const char *icolor = RED;
@@ -1475,6 +1479,7 @@ grab_binpkg_info(const char *name)
 	static char best_match[sizeof(Pkg.PF)+2+sizeof(Pkg.CATEGORY)];
 
 	best_match[0] = 0;
+	strcpy(pkg->SLOT,"0");
 
 	fp = open_binpkg_index();
 
@@ -1511,6 +1516,7 @@ grab_binpkg_info(const char *name)
 					atom_implode(atom);
 				}
 				memset(pkg, 0, sizeof(struct pkg_t));
+				strcpy(pkg->SLOT,"0");
 			}
 			continue;
 		}
@@ -1647,7 +1653,8 @@ static int
 parse_packages(queue *todo)
 {
 	FILE *fp;
-	size_t buflen, linelen;
+	int linelen;
+	size_t buflen;
 	char *buf, *p;
 	struct pkg_t Pkg;
 	depend_atom *pkg_atom;
@@ -1659,8 +1666,8 @@ parse_packages(queue *todo)
 	repo[0] = '\0';
 
 	/* First consume the header with the common data. */
-	while ((linelen = getline(&buf, &buflen, fp)) != -1) {
-		rmspace_len(buf, linelen);
+	while ((linelen = getline(&buf, &buflen, fp)) >= 0) {
+		rmspace_len(buf, (size_t)linelen);
 		if (buf[0] == '\0')
 			break;
 
@@ -1779,7 +1786,8 @@ static queue *
 qmerge_add_set_file(const char *dir, const char *file, queue *set)
 {
 	FILE *fp;
-	size_t buflen, linelen;
+	int linelen;
+	size_t buflen;
 	char *buf, *fname;
 
 	/* Find the file to read */
@@ -1794,8 +1802,8 @@ qmerge_add_set_file(const char *dir, const char *file, queue *set)
 
 	/* Load each entry */
 	buf = NULL;
-	while ((linelen = getline(&buf, &buflen, fp)) != -1) {
-		rmspace_len(buf, linelen);
+	while ((linelen = getline(&buf, &buflen, fp)) >= 0) {
+		rmspace_len(buf, (size_t)linelen);
 		set = add_set(buf, set);
 	}
 	free(buf);
