@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2014 Gentoo Foundation
+ * Copyright 2005-2018 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
  *
  * Copyright 2005-2008 Ned Ludd        - <solar@gentoo.org>
@@ -16,6 +16,12 @@ int main(int argc, char *argv[])
 {
 	int i, ret;
 
+	(void)xcalloc;
+	(void)xzalloc;
+	(void)xrealloc;
+	(void)xmemdup;
+	(void)rmdir_r_at;
+
 	if (argc <= 1)
 		return 1;
 
